<?php
/**
 * Dynamic Surveys Activator Class
 *
 * @package Dynamic Surveys
 * @since 1.0.2
 */

// Exit if accessed directly
if (!defined('ABSPATH')) {
    exit;
}

/**
 * Class Dynamic_Surveys_Activator
 * Handles plugin activation tasks
 */
class Dynamic_Surveys_Activator {
    
    /**
     * Activate the plugin
     *
     * @since 1.0.2
     * @return void
     */
    public static function activate() {
        self::create_tables();
        
        // Store the activation date
        add_option('dynamic_surveys_activated', current_time('mysql'));
        
        // Clear any existing rewrite rules
        flush_rewrite_rules();
    }
    
    /**
     * Create plugin database tables
     *
     * @since 1.0.2
     * @return void
     */
    private static function create_tables() {
        global $wpdb;
        
        // Get character set
        $charset_collate = $wpdb->get_charset_collate();
        
        // Define surveys table
        $sql_surveys = "CREATE TABLE IF NOT EXISTS {$wpdb->prefix}dynamic_surveys (
            id mediumint(9) NOT NULL AUTO_INCREMENT,
            title varchar(255) NOT NULL,
            question text NOT NULL,
            options longtext NOT NULL,
            status varchar(20) DEFAULT 'open',
            created_at datetime DEFAULT CURRENT_TIMESTAMP,
            PRIMARY KEY  (id)
        ) $charset_collate;";
        
        // Define votes table
        $sql_votes = "CREATE TABLE IF NOT EXISTS {$wpdb->prefix}dynamic_surveys_votes (
            id mediumint(9) NOT NULL AUTO_INCREMENT,
            survey_id mediumint(9) NOT NULL,
            user_id bigint(20) NOT NULL,
            option_id varchar(32) NOT NULL,
            ip_address varchar(45),
            created_at datetime DEFAULT CURRENT_TIMESTAMP,
            PRIMARY KEY  (id),
            KEY survey_user (survey_id, user_id),
            KEY survey_ip (survey_id, ip_address)
        ) $charset_collate;";
        
        // Include WordPress upgrade functions
        if (!function_exists('dbDelta')) {
            require_once(ABSPATH . 'wp-admin/includes/upgrade.php');
        }
        
        // Create/update tables
        dbDelta($sql_surveys);
        dbDelta($sql_votes);
    }
}